@@ -1,9 +1,10 @@
 package org.sqlite;
 
-import org.junit.jupiter.api.AfterEach;
-import org.junit.jupiter.api.Assumptions;
-import org.junit.jupiter.api.BeforeEach;
-import org.junit.jupiter.api.Test;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.io.InputStream;
 import java.sql.Connection;
@@ -18,16 +19,12 @@ import java.util.Arrays;
 import java.util.HashMap;
 import java.util.Map;
 import java.util.Properties;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.Assumptions;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertFalse;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertNull;
-import static org.junit.jupiter.api.Assertions.assertTrue;
-
-/**
- * These tests are designed to stress Statements on memory databases.
- */
+/** These tests are designed to stress Statements on memory databases. */
 public class DBMetaDataTest {
     private Connection conn;
     private Statement stat;
@@ -37,7 +34,8 @@ public class DBMetaDataTest {
     public void connect() throws Exception {
         conn = DriverManager.getConnection("jdbc:sqlite:");
         stat = conn.createStatement();
-        stat.executeUpdate("create table test (id integer primary key, fn float default 0.0, sn not null);");
+        stat.executeUpdate(
+                "create table test (id integer primary key, fn float default 0.0, sn not null);");
         stat.executeUpdate("create view testView as select * from test;");
         meta = conn.getMetaData();
     }
@@ -217,12 +215,14 @@ public class DBMetaDataTest {
     public void numberOfgetImportedKeysCols() throws SQLException {
 
         stat.executeUpdate("create table parent (id1 integer, id2 integer, primary key(id1, id2))");
-        stat.executeUpdate("create table child1 (id1 integer, id2 integer, foreign key(id1) references parent(id1), foreign key(id2) references parent(id2))");
-        stat.executeUpdate("create table child2 (id1 integer, id2 integer, foreign key(id2, id1) references parent(id2, id1))");
+        stat.executeUpdate(
+                "create table child1 (id1 integer, id2 integer, foreign key(id1) references parent(id1), foreign key(id2) references parent(id2))");
+        stat.executeUpdate(
+                "create table child2 (id1 integer, id2 integer, foreign key(id2, id1) references parent(id2, id1))");
 
         ResultSet importedKeys = meta.getImportedKeys(null, null, "child1");
 
-        //child1: 1st fk (simple)
+        // child1: 1st fk (simple)
         assertTrue(importedKeys.next());
         assertEquals("parent", importedKeys.getString("PKTABLE_NAME"));
         assertEquals("id2", importedKeys.getString("PKCOLUMN_NAME"));
@@ -231,7 +231,7 @@ public class DBMetaDataTest {
         assertEquals("child1", importedKeys.getString("FKTABLE_NAME"));
         assertEquals("id2", importedKeys.getString("FKCOLUMN_NAME"));
 
-        //child1: 2nd fk (simple)
+        // child1: 2nd fk (simple)
         assertTrue(importedKeys.next());
         assertEquals("parent", importedKeys.getString("PKTABLE_NAME"));
         assertEquals("id1", importedKeys.getString("PKCOLUMN_NAME"));
@@ -244,7 +244,7 @@ public class DBMetaDataTest {
 
         importedKeys = meta.getImportedKeys(null, null, "child2");
 
-        //child2: 1st fk (composite)
+        // child2: 1st fk (composite)
         assertTrue(importedKeys.next());
         assertEquals("parent", importedKeys.getString("PKTABLE_NAME"));
         assertEquals("id2", importedKeys.getString("PKCOLUMN_NAME"));
@@ -270,12 +270,14 @@ public class DBMetaDataTest {
     public void numberOfgetExportedKeysCols() throws SQLException {
 
         stat.executeUpdate("create table parent (id1 integer, id2 integer, primary key(id1, id2))");
-        stat.executeUpdate("create table child1 (id1 integer, id2 integer,\r\n foreign\tkey(id1) references parent(id1), foreign key(id2) references parent(id2))");
-        stat.executeUpdate("create table child2 (id1 integer, id2 integer, foreign key(id2, id1) references parent(id2, id1))");
+        stat.executeUpdate(
+                "create table child1 (id1 integer, id2 integer,\r\n foreign\tkey(id1) references parent(id1), foreign key(id2) references parent(id2))");
+        stat.executeUpdate(
+                "create table child2 (id1 integer, id2 integer, foreign key(id2, id1) references parent(id2, id1))");
 
         ResultSet exportedKeys = meta.getExportedKeys(null, null, "parent");
 
-        //1st fk (simple) - child1
+        // 1st fk (simple) - child1
         assertTrue(exportedKeys.next());
         assertEquals("parent", exportedKeys.getString("PKTABLE_NAME"));
         assertEquals("id2", exportedKeys.getString("PKCOLUMN_NAME"));
@@ -284,7 +286,7 @@ public class DBMetaDataTest {
         assertEquals("child1", exportedKeys.getString("FKTABLE_NAME"));
         assertEquals("id2", exportedKeys.getString("FKCOLUMN_NAME"));
 
-        //2nd fk (simple) - child1
+        // 2nd fk (simple) - child1
         assertTrue(exportedKeys.next());
         assertEquals("parent", exportedKeys.getString("PKTABLE_NAME"));
         assertEquals("id1", exportedKeys.getString("PKCOLUMN_NAME"));
@@ -293,7 +295,7 @@ public class DBMetaDataTest {
         assertEquals("child1", exportedKeys.getString("FKTABLE_NAME"));
         assertEquals("id1", exportedKeys.getString("FKCOLUMN_NAME"));
 
-        //3rd fk (composite) - child2
+        // 3rd fk (composite) - child2
         assertTrue(exportedKeys.next());
         assertEquals("parent", exportedKeys.getString("PKTABLE_NAME"));
         assertEquals("id2", exportedKeys.getString("PKCOLUMN_NAME"));
@@ -322,8 +324,10 @@ public class DBMetaDataTest {
 
         // 1. Check for named primary keys
         // SQL is deliberately in uppercase, to make sure case-sensitivity is maintained
-        stat.executeUpdate("CREATE TABLE PARENT1 (ID1 INTEGER, DATA1 INTEGER, CONSTRAINT PK_PARENT PRIMARY KEY (ID1))");
-        stat.executeUpdate("CREATE TABLE CHILD1 (ID1 INTEGER, DATA2 INTEGER, FOREIGN KEY(ID1) REFERENCES PARENT1(ID1))");
+        stat.executeUpdate(
+                "CREATE TABLE PARENT1 (ID1 INTEGER, DATA1 INTEGER, CONSTRAINT PK_PARENT PRIMARY KEY (ID1))");
+        stat.executeUpdate(
+                "CREATE TABLE CHILD1 (ID1 INTEGER, DATA2 INTEGER, FOREIGN KEY(ID1) REFERENCES PARENT1(ID1))");
 
         exportedKeys = meta.getExportedKeys(null, null, "PARENT1");
 
@@ -342,7 +346,8 @@ public class DBMetaDataTest {
         // 2. Check for named foreign keys
         // SQL is deliberately in mixed case, to make sure case-sensitivity is maintained
         stat.executeUpdate("CREATE TABLE Parent2 (Id1 INTEGER, DATA1 INTEGER, PRIMARY KEY (Id1))");
-        stat.executeUpdate("CREATE TABLE Child2 (Id1 INTEGER, DATA2 INTEGER, CONSTRAINT FK_Child2 FOREIGN KEY(Id1) REFERENCES Parent2(Id1))");
+        stat.executeUpdate(
+                "CREATE TABLE Child2 (Id1 INTEGER, DATA2 INTEGER, CONSTRAINT FK_Child2 FOREIGN KEY(Id1) REFERENCES Parent2(Id1))");
 
         exportedKeys = meta.getExportedKeys(null, null, "Parent2");
 
@@ -363,11 +368,11 @@ public class DBMetaDataTest {
     public void getImportedKeysMultipleColumns() throws SQLException {
         ResultSet importedKeys;
         stat.executeUpdate(
-            "CREATE TABLE PONE ( ID_FIRST_ONE INTEGER NOT NULL, ID_SECOND_ONE INTEGER NOT NULL, ADDITIONAL_ONE TEXT, CONSTRAINT PONE_PK PRIMARY KEY (ID_FIRST_ONE, ID_SECOND_ONE) )");
+                "CREATE TABLE PONE ( ID_FIRST_ONE INTEGER NOT NULL, ID_SECOND_ONE INTEGER NOT NULL, ADDITIONAL_ONE TEXT, CONSTRAINT PONE_PK PRIMARY KEY (ID_FIRST_ONE, ID_SECOND_ONE) )");
         stat.executeUpdate(
-            "CREATE TABLE PTWO ( ID_FIRST_TWO INTEGER NOT NULL, ID_SECOND_TWO INTEGER NOT NULL, ADDITIONAL_TWO TEXT, CONSTRAINT PTWO_PK PRIMARY KEY (ID_FIRST_TWO, ID_SECOND_TWO) )");
+                "CREATE TABLE PTWO ( ID_FIRST_TWO INTEGER NOT NULL, ID_SECOND_TWO INTEGER NOT NULL, ADDITIONAL_TWO TEXT, CONSTRAINT PTWO_PK PRIMARY KEY (ID_FIRST_TWO, ID_SECOND_TWO) )");
         stat.executeUpdate(
-            "CREATE TABLE CHILD ( ID_CHILD INTEGER NOT NULL, ID_CHILD_TO_ONE INTEGER NOT NULL, ID_CHILD_TO_TWO INTEGER NOT NULL, CONSTRAINT CHILD_PK PRIMARY KEY (ID_CHILD, ID_CHILD_TO_ONE), CONSTRAINT PONE_FK01 FOREIGN KEY (ID_CHILD, ID_CHILD_TO_ONE) REFERENCES PONE (ID_FIRST_ONE, ID_SECOND_ONE) ON DELETE CASCADE, CONSTRAINT PTWO_FK02 FOREIGN KEY (ID_CHILD, ID_CHILD_TO_TWO) REFERENCES PTWO (ID_FIRST_TWO, ID_SECOND_TWO) )");
+                "CREATE TABLE CHILD ( ID_CHILD INTEGER NOT NULL, ID_CHILD_TO_ONE INTEGER NOT NULL, ID_CHILD_TO_TWO INTEGER NOT NULL, CONSTRAINT CHILD_PK PRIMARY KEY (ID_CHILD, ID_CHILD_TO_ONE), CONSTRAINT PONE_FK01 FOREIGN KEY (ID_CHILD, ID_CHILD_TO_ONE) REFERENCES PONE (ID_FIRST_ONE, ID_SECOND_ONE) ON DELETE CASCADE, CONSTRAINT PTWO_FK02 FOREIGN KEY (ID_CHILD, ID_CHILD_TO_TWO) REFERENCES PTWO (ID_FIRST_TWO, ID_SECOND_TWO) )");
 
         importedKeys = meta.getImportedKeys(null, null, "CHILD");
 
@@ -414,8 +419,10 @@ public class DBMetaDataTest {
 
         // 1. Check for named primary keys
         // SQL is deliberately in uppercase, to make sure case-sensitivity is maintained
-        stat.executeUpdate("CREATE TABLE PARENT1 (ID1 INTEGER, DATA1 INTEGER, CONSTRAINT PK_PARENT PRIMARY KEY (ID1))");
-        stat.executeUpdate("CREATE TABLE CHILD1 (ID1 INTEGER, DATA2 INTEGER, FOREIGN KEY(ID1) REFERENCES PARENT1(ID1))");
+        stat.executeUpdate(
+                "CREATE TABLE PARENT1 (ID1 INTEGER, DATA1 INTEGER, CONSTRAINT PK_PARENT PRIMARY KEY (ID1))");
+        stat.executeUpdate(
+                "CREATE TABLE CHILD1 (ID1 INTEGER, DATA2 INTEGER, FOREIGN KEY(ID1) REFERENCES PARENT1(ID1))");
 
         importedKeys = meta.getImportedKeys(null, null, "CHILD1");
 
@@ -434,8 +441,9 @@ public class DBMetaDataTest {
         // 2. Check for named foreign keys
         // SQL is deliberately in mixed case, to make sure case-sensitivity is maintained
         stat.executeUpdate("CREATE TABLE Parent2 (Id1 INTEGER, DATA1 INTEGER, PRIMARY KEY (Id1))");
-        stat.executeUpdate("CREATE TABLE Child2 (Id1 INTEGER, DATA2 INTEGER, "
-            + "CONSTRAINT FK_Child2 FOREIGN KEY(Id1) REFERENCES Parent2(Id1))");
+        stat.executeUpdate(
+                "CREATE TABLE Child2 (Id1 INTEGER, DATA2 INTEGER, "
+                        + "CONSTRAINT FK_Child2 FOREIGN KEY(Id1) REFERENCES Parent2(Id1))");
 
         importedKeys = meta.getImportedKeys(null, null, "Child2");
 
@@ -458,9 +466,11 @@ public class DBMetaDataTest {
         ResultSet importedKeys;
 
         // SQL is deliberately in mixed-case, to make sure case-sensitivity is maintained
-        stat.executeUpdate("CREATE TABLE PARENT1 (ID1 INTEGER, DATA1 INTEGER, CONSTRAINT PK_PARENT PRIMARY KEY (ID1))");
-        stat.executeUpdate("CREATE TABLE CHILD1 (ID1 INTEGER, DATA2 INTEGER, "
-            + "CONSTRAINT FK_Parent1 FOREIGN KEY(ID1) REFERENCES Parent1(Id1))");
+        stat.executeUpdate(
+                "CREATE TABLE PARENT1 (ID1 INTEGER, DATA1 INTEGER, CONSTRAINT PK_PARENT PRIMARY KEY (ID1))");
+        stat.executeUpdate(
+                "CREATE TABLE CHILD1 (ID1 INTEGER, DATA2 INTEGER, "
+                        + "CONSTRAINT FK_Parent1 FOREIGN KEY(ID1) REFERENCES Parent1(Id1))");
 
         importedKeys = meta.getImportedKeys(null, null, "CHILD1");
 
@@ -482,11 +492,14 @@ public class DBMetaDataTest {
 
         ResultSet importedKeys;
 
-        stat.executeUpdate("CREATE TABLE PARENT1 (ID1 INTEGER, DATA1 INTEGER, CONSTRAINT PK_PARENT1 PRIMARY KEY (ID1))");
-        stat.executeUpdate("CREATE TABLE PARENT2 (ID2 INTEGER, DATA2 INTEGER, CONSTRAINT PK_PARENT2 PRIMARY KEY (ID2))");
-        stat.executeUpdate("CREATE TABLE CHILD1 (ID1 INTEGER, ID2 INTEGER, "
-            + "CONSTRAINT FK_PARENT1 FOREIGN KEY(ID1) REFERENCES PARENT1(ID1), "
-            + "CONSTRAINT FK_PARENT2 FOREIGN KEY(ID2) REFERENCES PARENT2(ID2))");
+        stat.executeUpdate(
+                "CREATE TABLE PARENT1 (ID1 INTEGER, DATA1 INTEGER, CONSTRAINT PK_PARENT1 PRIMARY KEY (ID1))");
+        stat.executeUpdate(
+                "CREATE TABLE PARENT2 (ID2 INTEGER, DATA2 INTEGER, CONSTRAINT PK_PARENT2 PRIMARY KEY (ID2))");
+        stat.executeUpdate(
+                "CREATE TABLE CHILD1 (ID1 INTEGER, ID2 INTEGER, "
+                        + "CONSTRAINT FK_PARENT1 FOREIGN KEY(ID1) REFERENCES PARENT1(ID1), "
+                        + "CONSTRAINT FK_PARENT2 FOREIGN KEY(ID2) REFERENCES PARENT2(ID2))");
 
         importedKeys = meta.getImportedKeys(null, null, "CHILD1");
 
@@ -512,10 +525,12 @@ public class DBMetaDataTest {
 
         // Unnamed foreign keys and unnamed primary keys
         stat.executeUpdate("CREATE TABLE PARENT3 (ID3 INTEGER, DATA3 INTEGER, PRIMARY KEY (ID3))");
-        stat.executeUpdate("CREATE TABLE PARENT4 (ID4 INTEGER, DATA4 INTEGER, CONSTRAINT PK_PARENT4 PRIMARY KEY (ID4))");
-        stat.executeUpdate("CREATE TABLE CHILD2 (ID3 INTEGER, ID4 INTEGER, "
-            + "FOREIGN KEY(ID3) REFERENCES PARENT3(ID3), "
-            + "CONSTRAINT FK_PARENT4 FOREIGN KEY(ID4) REFERENCES PARENT4(ID4))");
+        stat.executeUpdate(
+                "CREATE TABLE PARENT4 (ID4 INTEGER, DATA4 INTEGER, CONSTRAINT PK_PARENT4 PRIMARY KEY (ID4))");
+        stat.executeUpdate(
+                "CREATE TABLE CHILD2 (ID3 INTEGER, ID4 INTEGER, "
+                        + "FOREIGN KEY(ID3) REFERENCES PARENT3(ID3), "
+                        + "CONSTRAINT FK_PARENT4 FOREIGN KEY(ID4) REFERENCES PARENT4(ID4))");
 
         importedKeys = meta.getImportedKeys(null, null, "CHILD2");
 
@@ -543,15 +558,18 @@ public class DBMetaDataTest {
     @Test
     public void getImportedKeysCols2() throws SQLException {
 
-        stat.executeUpdate("CREATE TABLE Authors (Id INTEGER NOT NULL, Name VARCHAR(20) NOT NULL, "
-            + "CONSTRAINT PK_Authors PRIMARY KEY (Id)," +
-            "  CONSTRAINT CHECK_UPPERCASE_Name CHECK (Name=UPPER(Name)))");
-        stat.executeUpdate("CREATE TABLE Books (Id INTEGER NOT NULL, Title VARCHAR(255) NOT NULL, PreviousEditionId INTEGER,"
-            + "CONSTRAINT PK_Books PRIMARY KEY (Id), "
-            + "CONSTRAINT FK_PreviousEdition FOREIGN KEY(PreviousEditionId) REFERENCES Books (Id))");
-        stat.executeUpdate("CREATE TABLE BookAuthors (BookId INTEGER NOT NULL, AuthorId INTEGER NOT NULL, "
-            + "CONSTRAINT FK_Y_Book FOREIGN KEY (BookId) REFERENCES Books (Id), "
-            + "CONSTRAINT FK_Z_Author FOREIGN KEY (AuthorId) REFERENCES Authors (Id)) ");
+        stat.executeUpdate(
+                "CREATE TABLE Authors (Id INTEGER NOT NULL, Name VARCHAR(20) NOT NULL, "
+                        + "CONSTRAINT PK_Authors PRIMARY KEY (Id),"
+                        + "  CONSTRAINT CHECK_UPPERCASE_Name CHECK (Name=UPPER(Name)))");
+        stat.executeUpdate(
+                "CREATE TABLE Books (Id INTEGER NOT NULL, Title VARCHAR(255) NOT NULL, PreviousEditionId INTEGER,"
+                        + "CONSTRAINT PK_Books PRIMARY KEY (Id), "
+                        + "CONSTRAINT FK_PreviousEdition FOREIGN KEY(PreviousEditionId) REFERENCES Books (Id))");
+        stat.executeUpdate(
+                "CREATE TABLE BookAuthors (BookId INTEGER NOT NULL, AuthorId INTEGER NOT NULL, "
+                        + "CONSTRAINT FK_Y_Book FOREIGN KEY (BookId) REFERENCES Books (Id), "
+                        + "CONSTRAINT FK_Z_Author FOREIGN KEY (AuthorId) REFERENCES Authors (Id)) ");
 
         ResultSet importedKeys;
 
@@ -577,7 +595,6 @@ public class DBMetaDataTest {
 
         importedKeys.close();
 
-
         ResultSet exportedKeys;
 
         exportedKeys = meta.getExportedKeys(null, null, "Authors");
@@ -622,9 +639,12 @@ public class DBMetaDataTest {
 
         ResultSet exportedKeys;
 
-        stat.executeUpdate("CREATE TABLE PARENT1 (ID1 INTEGER, ID2 INTEGER, CONSTRAINT PK_PARENT1 PRIMARY KEY (ID1))");
-        stat.executeUpdate("CREATE TABLE CHILD1 (ID1 INTEGER, CONSTRAINT FK_PARENT1 FOREIGN KEY(ID1) REFERENCES PARENT1(ID1))");
-        stat.executeUpdate("CREATE TABLE CHILD2 (ID2 INTEGER, CONSTRAINT FK_PARENT2 FOREIGN KEY(ID2) REFERENCES PARENT1(ID2))");
+        stat.executeUpdate(
+                "CREATE TABLE PARENT1 (ID1 INTEGER, ID2 INTEGER, CONSTRAINT PK_PARENT1 PRIMARY KEY (ID1))");
+        stat.executeUpdate(
+                "CREATE TABLE CHILD1 (ID1 INTEGER, CONSTRAINT FK_PARENT1 FOREIGN KEY(ID1) REFERENCES PARENT1(ID1))");
+        stat.executeUpdate(
+                "CREATE TABLE CHILD2 (ID2 INTEGER, CONSTRAINT FK_PARENT2 FOREIGN KEY(ID2) REFERENCES PARENT1(ID2))");
 
         exportedKeys = meta.getExportedKeys(null, null, "PARENT1");
 
@@ -652,12 +672,18 @@ public class DBMetaDataTest {
     @Test
     public void columnOrderOfgetTables() throws SQLException {
 
-        stat.executeUpdate("CREATE TABLE TABLE1 (ID1 INTEGER PRIMARY KEY AUTOINCREMENT, ID2 INTEGER)");
+        stat.executeUpdate(
+                "CREATE TABLE TABLE1 (ID1 INTEGER PRIMARY KEY AUTOINCREMENT, ID2 INTEGER)");
         stat.executeUpdate("CREATE TABLE TABLE2 (ID2 INTEGER, DATA2 VARCHAR(20))");
         stat.executeUpdate("CREATE TEMP TABLE TABLE3 (ID3 INTEGER, DATA3 VARCHAR(20))");
         stat.executeUpdate("CREATE VIEW VIEW1 (V1, V2) AS SELECT ID1, ID2 FROM TABLE1");
 
-        ResultSet rsTables = meta.getTables(null, null, null, new String[] {"TABLE", "VIEW", "GLOBAL TEMPORARY", "SYSTEM TABLE"});
+        ResultSet rsTables =
+                meta.getTables(
+                        null,
+                        null,
+                        null,
+                        new String[] {"TABLE", "VIEW", "GLOBAL TEMPORARY", "SYSTEM TABLE"});
 
         assertTrue(rsTables.next());
 
@@ -950,7 +976,6 @@ public class DBMetaDataTest {
         assertEquals(rs.getString("COLUMN_NAME"), "Col2");
         assertEquals(rs.getInt("DATA_TYPE"), Types.VARCHAR);
         assertFalse(rs.next());
-
     }
 
     @Test
@@ -958,11 +983,13 @@ public class DBMetaDataTest {
         ResultSet rs;
 
         // no autoincrement no rowid
-        stat.executeUpdate("CREATE TABLE TAB1 (COL1 INTEGER NOT NULL PRIMARY KEY, COL2) WITHOUT ROWID;");
+        stat.executeUpdate(
+                "CREATE TABLE TAB1 (COL1 INTEGER NOT NULL PRIMARY KEY, COL2) WITHOUT ROWID;");
         // no autoincrement
         stat.executeUpdate("CREATE TABLE TAB2 (COL1 INTEGER NOT NULL PRIMARY KEY, COL2);");
         // autoincrement
-        stat.executeUpdate("CREATE TABLE TAB3 (COL1 INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT, COL2);");
+        stat.executeUpdate(
+                "CREATE TABLE TAB3 (COL1 INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT, COL2);");
 
         rs = meta.getColumns(null, null, "TAB1", "%");
         assertTrue(rs.next());
@@ -1005,7 +1032,6 @@ public class DBMetaDataTest {
         assertEquals(rs.getString("COLUMN_NAME"), "COL2");
         assertEquals(rs.getInt("DATA_TYPE"), Types.VARCHAR);
         assertFalse(rs.next());
-
     }
 
     @Test
@@ -1016,25 +1042,37 @@ public class DBMetaDataTest {
         stat.executeUpdate("create table nopk (c1, c2, c3, c4);");
         stat.executeUpdate("create table pk1 (col1 primary key, col2, col3);");
         stat.executeUpdate("create table pk2 (col1, col2 primary key, col3);");
-        stat.executeUpdate("create table pk3 (col1, col2, col3, col4, primary key (col3, col2  ));");
-        // extra spaces and mixed case are intentional, do not remove!
-        stat.executeUpdate("create table pk4 (col1, col2, col3, col4, " +
-            "\r\nCONSTraint\r\nnamed  primary\r\n\t\t key   (col3, col2  ));");
-        // mixed-case table, column and primary key names - GitHub issue #219
-        stat.executeUpdate("CREATE TABLE Pk5 (Col1, Col2, Col3, Col4, CONSTRAINT NamedPk PRIMARY KEY (Col3, Col2));");
-        // quoted table, column and primary key names - GitHub issue #219
-        stat.executeUpdate("CREATE TABLE `Pk6` (`Col1`, `Col2`, `Col3`, `Col4`, CONSTRAINT `NamedPk` PRIMARY KEY (`Col3`, `Col2`));");
-        // spaces before and after "primary key" - GitHub issue #236
-        stat.executeUpdate("CREATE TABLE pk7 (col1, col2, col3, col4 VARCHAR(10),PRIMARY KEY (col1, col2, col3));");
-        stat.executeUpdate("CREATE TABLE pk8 (col1, col2, col3, col4 VARCHAR(10), PRIMARY KEY(col1, col2, col3));");
-        stat.executeUpdate("CREATE TABLE pk9 (col1, col2, col3, col4 VARCHAR(10),PRIMARY KEY(col1, col2, col3));");
-        stat.executeUpdate("CREATE TABLE `Pk10` (`Col1`, `Col2`, `Col3`, `Col4`, CONSTRAINT `NamedPk`PRIMARY KEY (`Col3`, `Col2`));");
-        stat.executeUpdate("CREATE TABLE `Pk11` (`Col1`, `Col2`, `Col3`, `Col4`, CONSTRAINT `NamedPk` PRIMARY KEY(`Col3`, `Col2`));");
-        stat.executeUpdate("CREATE TABLE `Pk12` (`Col1`, `Col2`, `Col3`, `Col4`, CONSTRAINT`NamedPk`PRIMARY KEY(`Col3`,`Col2`));");
-        stat.executeUpdate("CREATE TABLE \"Pk13\" (\"Col1\", \"Col2\", \"Col3\", \"Col4\", CONSTRAINT \"NamedPk\" PRIMARY KEY(\"Col3\",\"Col2\"));");
-        stat.executeUpdate("CREATE TABLE \"Pk14\" (\"Col1\", \"Col2\", \"Col3\", \"Col4\", PRIMARY KEY(\"Col3\"), FOREIGN KEY (\"Col1\") REFERENCES \"pk1\" (\"col1\"))");
         stat.executeUpdate(
-            "CREATE TABLE \"Pk15\" (\"Col1\", \"Col2\", \"Col3\", \"Col4\", PRIMARY KEY(\"Col3\", \"Col2\"), FOREIGN KEY (\"Col1\") REFERENCES \"pk1\" (\"col1\"))");
+                "create table pk3 (col1, col2, col3, col4, primary key (col3, col2  ));");
+        // extra spaces and mixed case are intentional, do not remove!
+        stat.executeUpdate(
+                "create table pk4 (col1, col2, col3, col4, "
+                        + "\r\nCONSTraint\r\nnamed  primary\r\n\t\t key   (col3, col2  ));");
+        // mixed-case table, column and primary key names - GitHub issue #219
+        stat.executeUpdate(
+                "CREATE TABLE Pk5 (Col1, Col2, Col3, Col4, CONSTRAINT NamedPk PRIMARY KEY (Col3, Col2));");
+        // quoted table, column and primary key names - GitHub issue #219
+        stat.executeUpdate(
+                "CREATE TABLE `Pk6` (`Col1`, `Col2`, `Col3`, `Col4`, CONSTRAINT `NamedPk` PRIMARY KEY (`Col3`, `Col2`));");
+        // spaces before and after "primary key" - GitHub issue #236
+        stat.executeUpdate(
+                "CREATE TABLE pk7 (col1, col2, col3, col4 VARCHAR(10),PRIMARY KEY (col1, col2, col3));");
+        stat.executeUpdate(
+                "CREATE TABLE pk8 (col1, col2, col3, col4 VARCHAR(10), PRIMARY KEY(col1, col2, col3));");
+        stat.executeUpdate(
+                "CREATE TABLE pk9 (col1, col2, col3, col4 VARCHAR(10),PRIMARY KEY(col1, col2, col3));");
+        stat.executeUpdate(
+                "CREATE TABLE `Pk10` (`Col1`, `Col2`, `Col3`, `Col4`, CONSTRAINT `NamedPk`PRIMARY KEY (`Col3`, `Col2`));");
+        stat.executeUpdate(
+                "CREATE TABLE `Pk11` (`Col1`, `Col2`, `Col3`, `Col4`, CONSTRAINT `NamedPk` PRIMARY KEY(`Col3`, `Col2`));");
+        stat.executeUpdate(
+                "CREATE TABLE `Pk12` (`Col1`, `Col2`, `Col3`, `Col4`, CONSTRAINT`NamedPk`PRIMARY KEY(`Col3`,`Col2`));");
+        stat.executeUpdate(
+                "CREATE TABLE \"Pk13\" (\"Col1\", \"Col2\", \"Col3\", \"Col4\", CONSTRAINT \"NamedPk\" PRIMARY KEY(\"Col3\",\"Col2\"));");
+        stat.executeUpdate(
+                "CREATE TABLE \"Pk14\" (\"Col1\", \"Col2\", \"Col3\", \"Col4\", PRIMARY KEY(\"Col3\"), FOREIGN KEY (\"Col1\") REFERENCES \"pk1\" (\"col1\"))");
+        stat.executeUpdate(
+                "CREATE TABLE \"Pk15\" (\"Col1\", \"Col2\", \"Col3\", \"Col4\", PRIMARY KEY(\"Col3\", \"Col2\"), FOREIGN KEY (\"Col1\") REFERENCES \"pk1\" (\"col1\"))");
 
         rs = meta.getPrimaryKeys(null, null, "nopk");
         assertFalse(rs.next());
@@ -1065,7 +1103,9 @@ public class DBMetaDataTest {
         assertPrimaryKey(meta, "Pk15", null, "Col3", "Col2");
     }
 
-    private void assertPrimaryKey(DatabaseMetaData meta, String tableName, String pkName, String... pkColumns) throws Exception {
+    private void assertPrimaryKey(
+            DatabaseMetaData meta, String tableName, String pkName, String... pkColumns)
+            throws Exception {
         final Map<String, Integer> colSeq = new HashMap<String, Integer>();
         for (int i = 0; i < pkColumns.length; i++) {
             colSeq.put(pkColumns[i], i + 1);
@@ -1077,10 +1117,20 @@ public class DBMetaDataTest {
         for (int i = 0; i < pkColumns.length; i++) {
             assertNull(rs.getString("TABLE_CAT"), "DatabaseMetaData.getPrimaryKeys: TABLE_CAT");
             assertNull(rs.getString("TABLE_SCHEM"), "DatabaseMetaData.getPrimaryKeys: TABLE_SCHEM");
-            assertEquals(tableName, rs.getString("TABLE_NAME"), "DatabaseMetaData.getPrimaryKeys: TABLE_NAME");
-            assertEquals(pkColumns[i], rs.getString("COLUMN_NAME"), "DatabaseMetaData.getPrimaryKeys: COLUMN_NAME");
-            assertEquals(pkName, rs.getString("PK_NAME"), "DatabaseMetaData.getPrimaryKeys: PK_NAME");
-            assertEquals(colSeq.get(pkColumns[i]).intValue(), rs.getInt("KEY_SEQ"), "DatabaseMetaData.getPrimaryKeys: KEY_SEQ");
+            assertEquals(
+                    tableName,
+                    rs.getString("TABLE_NAME"),
+                    "DatabaseMetaData.getPrimaryKeys: TABLE_NAME");
+            assertEquals(
+                    pkColumns[i],
+                    rs.getString("COLUMN_NAME"),
+                    "DatabaseMetaData.getPrimaryKeys: COLUMN_NAME");
+            assertEquals(
+                    pkName, rs.getString("PK_NAME"), "DatabaseMetaData.getPrimaryKeys: PK_NAME");
+            assertEquals(
+                    colSeq.get(pkColumns[i]).intValue(),
+                    rs.getInt("KEY_SEQ"),
+                    "DatabaseMetaData.getPrimaryKeys: KEY_SEQ");
             if (i < pkColumns.length - 1) assertTrue(rs.next());
         }
 
@@ -1093,7 +1143,8 @@ public class DBMetaDataTest {
     public void columnOrderOfgetImportedKeys() throws SQLException {
 
         stat.executeUpdate("create table person (id integer)");
-        stat.executeUpdate("create table address (pid integer, name, foreign key(pid) references person(id))");
+        stat.executeUpdate(
+                "create table address (pid integer, name, foreign key(pid) references person(id))");
 
         ResultSet importedKeys = meta.getImportedKeys("default", "global", "address");
         assertTrue(importedKeys.next());
@@ -1117,7 +1168,8 @@ public class DBMetaDataTest {
     public void columnOrderOfgetExportedKeys() throws SQLException {
 
         stat.executeUpdate("create table person (id integer primary key)");
-        stat.executeUpdate("create table address (pid integer, name, foreign key(pid) references person(id))");
+        stat.executeUpdate(
+                "create table address (pid integer, name, foreign key(pid) references person(id))");
 
         ResultSet exportedKeys = meta.getExportedKeys("default", "global", "person");
         assertTrue(exportedKeys.next());
@@ -1141,7 +1193,8 @@ public class DBMetaDataTest {
 
         // With explicit primary column defined.
         stat.executeUpdate("create table REFERRED (ID integer primary key not null)");
-        stat.executeUpdate("create table REFERRING (ID integer, RID integer, constraint fk\r\n foreign\tkey\r\n(RID) references REFERRED(id))");
+        stat.executeUpdate(
+                "create table REFERRING (ID integer, RID integer, constraint fk\r\n foreign\tkey\r\n(RID) references REFERRED(id))");
 
         exportedKeys = meta.getExportedKeys(null, null, "referred");
         assertEquals("REFERRED", exportedKeys.getString("PKTABLE_NAME"));
@@ -1153,15 +1206,16 @@ public class DBMetaDataTest {
     @Test
     public void columnOrderOfgetCrossReference() throws SQLException {
         stat.executeUpdate("create table person (id integer)");
-        stat.executeUpdate("create table address (pid integer, name, foreign key(pid) references person(id))");
+        stat.executeUpdate(
+                "create table address (pid integer, name, foreign key(pid) references person(id))");
 
         ResultSet cr = meta.getCrossReference(null, null, "person", null, null, "address");
-        //assertTrue(cr.next());
+        // assertTrue(cr.next());
 
     }
 
     /* TODO
-    
+
     @Test public void columnOrderOfgetTypeInfo() throws SQLException {
     @Test public void columnOrderOfgetIndexInfo() throws SQLException {
     @Test public void columnOrderOfgetSuperTypes() throws SQLException {
@@ -1192,7 +1246,8 @@ public class DBMetaDataTest {
 
     @Test
     public void getIndexInfoIndexedSingle() throws SQLException {
-        stat.executeUpdate("create table testindex (id integer primary key, fn float default 0.0, sn not null);");
+        stat.executeUpdate(
+                "create table testindex (id integer primary key, fn float default 0.0, sn not null);");
         stat.executeUpdate("create index testindex_idx on testindex (sn);");
 
         ResultSet rs = meta.getIndexInfo(null, null, "testindex", false, false);
@@ -1202,10 +1257,10 @@ public class DBMetaDataTest {
         assertNotNull(rsmd);
     }
 
-
     @Test
     public void getIndexInfoIndexedSingleExpr() throws SQLException {
-        stat.executeUpdate("create table testindex (id integer primary key, fn float default 0.0, sn not null);");
+        stat.executeUpdate(
+                "create table testindex (id integer primary key, fn float default 0.0, sn not null);");
         stat.executeUpdate("create index testindex_idx on testindex (sn, fn/2);");
 
         ResultSet rs = meta.getIndexInfo(null, null, "testindex", false, false);
@@ -1215,10 +1270,10 @@ public class DBMetaDataTest {
         assertNotNull(rsmd);
     }
 
-
     @Test
     public void getIndexInfoIndexedMulti() throws SQLException {
-        stat.executeUpdate("create table testindex (id integer primary key, fn float default 0.0, sn not null);");
+        stat.executeUpdate(
+                "create table testindex (id integer primary key, fn float default 0.0, sn not null);");
         stat.executeUpdate("create index testindex_idx on testindex (sn);");
         stat.executeUpdate("create index testindex_pk_idx on testindex (id);");
 
@@ -1229,11 +1284,12 @@ public class DBMetaDataTest {
         assertNotNull(rsmd);
     }
 
-
     @Test
     public void version() throws Exception {
         Properties version;
-        try (InputStream resourceAsStream = DBMetaDataTest.class.getResourceAsStream("/META-INF/maven/org.xerial/sqlite-jdbc/VERSION")) {
+        try (InputStream resourceAsStream =
+                DBMetaDataTest.class.getResourceAsStream(
+                        "/META-INF/maven/org.xerial/sqlite-jdbc/VERSION")) {
             version = new Properties();
             Assumptions.assumeTrue(resourceAsStream != null);
             version.load(resourceAsStream);
@@ -1244,7 +1300,10 @@ public class DBMetaDataTest {
 
         assertTrue(majorVersion > 0, "major version check");
         assertEquals("SQLite JDBC", meta.getDriverName(), "driver name");
-        assertTrue(meta.getDriverVersion().startsWith(String.format("%d.%d", majorVersion, minorVersion)), "driver version");
+        assertTrue(
+                meta.getDriverVersion()
+                        .startsWith(String.format("%d.%d", majorVersion, minorVersion)),
+                "driver version");
         assertEquals(majorVersion, meta.getDriverMajorVersion(), "driver major version");
         assertEquals(minorVersion, meta.getDriverMinorVersion(), "driver minor version");
         assertEquals("SQLite", meta.getDatabaseProductName(), "db name");
@@ -1253,5 +1312,4 @@ public class DBMetaDataTest {
         assertEquals(minorVersion, meta.getDatabaseMinorVersion(), "db minor version");
         assertNull(meta.getUserName(), "user name");
     }
-
 }
