@@ -1,15 +1,14 @@
 package org.sqlite;
 
-import org.junit.jupiter.api.Test;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.sql.Connection;
 import java.sql.DriverManager;
 import java.sql.ResultSet;
 import java.sql.SQLException;
-
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertFalse;
-import static org.junit.jupiter.api.Assertions.assertTrue;
+import org.junit.jupiter.api.Test;
 
 /**
  * Tests the JSON1 extension using the examples listed in the documentation.
@@ -26,7 +25,10 @@ public class JSON1Test {
     public void json_Test() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json(' { \"this\" : \"is\", \"a\": [ \"test\" ] } ')");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery(
+                                "select json(' { \"this\" : \"is\", \"a\": [ \"test\" ] } ')");
         assertTrue(rs.next());
         assertEquals("{\"this\":\"is\",\"a\":[\"test\"]}", rs.getString(1));
     }
@@ -35,7 +37,8 @@ public class JSON1Test {
     public void json_object_Test1() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_object('ex','[52,3.14159]')");
+        ResultSet rs =
+                conn.createStatement().executeQuery("select json_object('ex','[52,3.14159]')");
         assertTrue(rs.next());
         assertEquals("{\"ex\":\"[52,3.14159]\"}", rs.getString(1));
     }
@@ -44,7 +47,9 @@ public class JSON1Test {
     public void json_object_Test2() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_object('ex',json('[52,3.14159]'))");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery("select json_object('ex',json('[52,3.14159]'))");
         assertTrue(rs.next());
         assertEquals("{\"ex\":[52,3.14159]}", rs.getString(1));
     }
@@ -53,7 +58,9 @@ public class JSON1Test {
     public void json_object_Test3() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_object('ex',json_array(52,3.14159))");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery("select json_object('ex',json_array(52,3.14159))");
         assertTrue(rs.next());
         assertEquals("{\"ex\":[52,3.14159]}", rs.getString(1));
     }
@@ -80,7 +87,9 @@ public class JSON1Test {
     public void json_object_Test6() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_object('a',2,'c',json_object('e',5))");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery("select json_object('a',2,'c',json_object('e',5))");
         assertTrue(rs.next());
         assertEquals("{\"a\":2,\"c\":{\"e\":5}}", rs.getString(1));
     }
@@ -116,7 +125,9 @@ public class JSON1Test {
     public void json_array_Test4() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_array(1,null,'3','[4,5]','{\"six\":7.7}')");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery("select json_array(1,null,'3','[4,5]','{\"six\":7.7}')");
         assertTrue(rs.next());
         assertEquals("[1,null,\"3\",\"[4,5]\",\"{\\\"six\\\":7.7}\"]", rs.getString(1));
     }
@@ -125,7 +136,10 @@ public class JSON1Test {
     public void json_array_Test5() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_array(1,null,'3',json('[4,5]'),json('{\"six\":7.7}'))");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery(
+                                "select json_array(1,null,'3',json('[4,5]'),json('{\"six\":7.7}'))");
         assertTrue(rs.next());
         assertEquals("[1,null,\"3\",[4,5],{\"six\":7.7}]", rs.getString(1));
     }
@@ -143,7 +157,8 @@ public class JSON1Test {
     public void json_array_length_Test2() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_array_length('[1,2,3,4]', '$')");
+        ResultSet rs =
+                conn.createStatement().executeQuery("select json_array_length('[1,2,3,4]', '$')");
         assertTrue(rs.next());
         assertEquals(4, rs.getInt(1));
     }
@@ -152,7 +167,9 @@ public class JSON1Test {
     public void json_array_length_Test3() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_array_length('[1,2,3,4]', '$[2]')");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery("select json_array_length('[1,2,3,4]', '$[2]')");
         assertTrue(rs.next());
         assertEquals(0, rs.getInt(1));
     }
@@ -161,7 +178,9 @@ public class JSON1Test {
     public void json_array_length_Test4() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_array_length('{\"one\":[1,2,3]}')");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery("select json_array_length('{\"one\":[1,2,3]}')");
         assertTrue(rs.next());
         assertEquals(0, rs.getInt(1));
     }
@@ -170,7 +189,9 @@ public class JSON1Test {
     public void json_array_length_Test5() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_array_length('{\"one\":[1,2,3]}', '$.one')");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery("select json_array_length('{\"one\":[1,2,3]}', '$.one')");
         assertTrue(rs.next());
         assertEquals(3, rs.getInt(1));
     }
@@ -179,7 +200,9 @@ public class JSON1Test {
     public void json_array_length_Test6() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_array_length('{\"one\":[1,2,3]}', '$.two')");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery("select json_array_length('{\"one\":[1,2,3]}', '$.two')");
         assertTrue(rs.next());
         assertEquals(null, rs.getObject(1));
     }
@@ -188,7 +211,10 @@ public class JSON1Test {
     public void json_extract_Test1() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_extract('{\"a\":2,\"c\":[4,5,{\"f\":7}]}', '$')");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery(
+                                "select json_extract('{\"a\":2,\"c\":[4,5,{\"f\":7}]}', '$')");
         assertTrue(rs.next());
         assertEquals("{\"a\":2,\"c\":[4,5,{\"f\":7}]}", rs.getString(1));
     }
@@ -197,7 +223,10 @@ public class JSON1Test {
     public void json_extract_Test2() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_extract('{\"a\":2,\"c\":[4,5,{\"f\":7}]}', '$.c')");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery(
+                                "select json_extract('{\"a\":2,\"c\":[4,5,{\"f\":7}]}', '$.c')");
         assertTrue(rs.next());
         assertEquals("[4,5,{\"f\":7}]", rs.getString(1));
     }
@@ -206,7 +235,10 @@ public class JSON1Test {
     public void json_extract_Test3() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_extract('{\"a\":2,\"c\":[4,5,{\"f\":7}]}', '$.c[2]')");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery(
+                                "select json_extract('{\"a\":2,\"c\":[4,5,{\"f\":7}]}', '$.c[2]')");
         assertTrue(rs.next());
         assertEquals("{\"f\":7}", rs.getString(1));
     }
@@ -215,7 +247,10 @@ public class JSON1Test {
     public void json_extract_Test4() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_extract('{\"a\":2,\"c\":[4,5,{\"f\":7}]}', '$.c[2].f')");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery(
+                                "select json_extract('{\"a\":2,\"c\":[4,5,{\"f\":7}]}', '$.c[2].f')");
         assertTrue(rs.next());
         assertEquals(7, rs.getInt(1));
     }
@@ -224,7 +259,10 @@ public class JSON1Test {
     public void json_extract_Test5() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_extract('{\"a\":2,\"c\":[4,5],\"f\":7}','$.c','$.a')");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery(
+                                "select json_extract('{\"a\":2,\"c\":[4,5],\"f\":7}','$.c','$.a')");
         assertTrue(rs.next());
         assertEquals("[[4,5],2]", rs.getString(1));
     }
@@ -233,7 +271,10 @@ public class JSON1Test {
     public void json_extract_Test6() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_extract('{\"a\":2,\"c\":[4,5,{\"f\":7}]}', '$.x')");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery(
+                                "select json_extract('{\"a\":2,\"c\":[4,5,{\"f\":7}]}', '$.x')");
         assertTrue(rs.next());
         assertEquals(null, rs.getString(1));
     }
@@ -242,7 +283,10 @@ public class JSON1Test {
     public void json_extract_Test7() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_extract('{\"a\":2,\"c\":[4,5,{\"f\":7}]}', '$.x', '$.a')");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery(
+                                "select json_extract('{\"a\":2,\"c\":[4,5,{\"f\":7}]}', '$.x', '$.a')");
         assertTrue(rs.next());
         assertEquals("[null,2]", rs.getString(1));
     }
@@ -251,7 +295,9 @@ public class JSON1Test {
     public void json_insert_Test1() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_insert('{\"a\":2,\"c\":4}', '$.a', 99)");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery("select json_insert('{\"a\":2,\"c\":4}', '$.a', 99)");
         assertTrue(rs.next());
         assertEquals("{\"a\":2,\"c\":4}", rs.getString(1));
     }
@@ -260,7 +306,9 @@ public class JSON1Test {
     public void json_insert_Test2() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_insert('{\"a\":2,\"c\":4}', '$.e', 99)");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery("select json_insert('{\"a\":2,\"c\":4}', '$.e', 99)");
         assertTrue(rs.next());
         assertEquals("{\"a\":2,\"c\":4,\"e\":99}", rs.getString(1));
     }
@@ -269,7 +317,9 @@ public class JSON1Test {
     public void json_replace_Test1() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_replace('{\"a\":2,\"c\":4}', '$.a', 99)");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery("select json_replace('{\"a\":2,\"c\":4}', '$.a', 99)");
         assertTrue(rs.next());
         assertEquals("{\"a\":99,\"c\":4}", rs.getString(1));
     }
@@ -278,7 +328,9 @@ public class JSON1Test {
     public void json_replace_Test2() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_replace('{\"a\":2,\"c\":4}', '$.e', 99)");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery("select json_replace('{\"a\":2,\"c\":4}', '$.e', 99)");
         assertTrue(rs.next());
         assertEquals("{\"a\":2,\"c\":4}", rs.getString(1));
     }
@@ -287,7 +339,9 @@ public class JSON1Test {
     public void json_set_Test1() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_set('{\"a\":2,\"c\":4}', '$.a', 99)");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery("select json_set('{\"a\":2,\"c\":4}', '$.a', 99)");
         assertTrue(rs.next());
         assertEquals("{\"a\":99,\"c\":4}", rs.getString(1));
     }
@@ -296,7 +350,9 @@ public class JSON1Test {
     public void json_set_Test2() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_set('{\"a\":2,\"c\":4}', '$.e', 99)");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery("select json_set('{\"a\":2,\"c\":4}', '$.e', 99)");
         assertTrue(rs.next());
         assertEquals("{\"a\":2,\"c\":4,\"e\":99}", rs.getString(1));
     }
@@ -305,7 +361,9 @@ public class JSON1Test {
     public void json_set_Test3() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_set('{\"a\":2,\"c\":4}', '$.c', '[97,96]')");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery("select json_set('{\"a\":2,\"c\":4}', '$.c', '[97,96]')");
         assertTrue(rs.next());
         assertEquals("{\"a\":2,\"c\":\"[97,96]\"}", rs.getString(1));
     }
@@ -314,7 +372,10 @@ public class JSON1Test {
     public void json_set_Test4() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_set('{\"a\":2,\"c\":4}', '$.c', json('[97,96]'))");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery(
+                                "select json_set('{\"a\":2,\"c\":4}', '$.c', json('[97,96]'))");
         assertTrue(rs.next());
         assertEquals("{\"a\":2,\"c\":[97,96]}", rs.getString(1));
     }
@@ -323,7 +384,10 @@ public class JSON1Test {
     public void json_set_Test5() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_set('{\"a\":2,\"c\":4}', '$.c', json_array(97,96))");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery(
+                                "select json_set('{\"a\":2,\"c\":4}', '$.c', json_array(97,96))");
         assertTrue(rs.next());
         assertEquals("{\"a\":2,\"c\":[97,96]}", rs.getString(1));
     }
@@ -332,7 +396,8 @@ public class JSON1Test {
     public void json_remove_Test1() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_remove('[0,1,2,3,4]','$[2]')");
+        ResultSet rs =
+                conn.createStatement().executeQuery("select json_remove('[0,1,2,3,4]','$[2]')");
         assertTrue(rs.next());
         assertEquals("[0,1,3,4]", rs.getString(1));
     }
@@ -341,7 +406,9 @@ public class JSON1Test {
     public void json_remove_Test2() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_remove('[0,1,2,3,4]','$[2]','$[0]')");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery("select json_remove('[0,1,2,3,4]','$[2]','$[0]')");
         assertTrue(rs.next());
         assertEquals("[1,3,4]", rs.getString(1));
     }
@@ -350,7 +417,9 @@ public class JSON1Test {
     public void json_remove_Test3() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_remove('[0,1,2,3,4]','$[0]','$[2]')");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery("select json_remove('[0,1,2,3,4]','$[0]','$[2]')");
         assertTrue(rs.next());
         assertEquals("[1,2,4]", rs.getString(1));
     }
@@ -359,7 +428,8 @@ public class JSON1Test {
     public void json_remove_Test4() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_remove('{\"x\":25,\"y\":42}')");
+        ResultSet rs =
+                conn.createStatement().executeQuery("select json_remove('{\"x\":25,\"y\":42}')");
         assertTrue(rs.next());
         assertEquals("{\"x\":25,\"y\":42}", rs.getString(1));
     }
@@ -368,7 +438,9 @@ public class JSON1Test {
     public void json_remove_Test5() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_remove('{\"x\":25,\"y\":42}','$.z')");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery("select json_remove('{\"x\":25,\"y\":42}','$.z')");
         assertTrue(rs.next());
         assertEquals("{\"x\":25,\"y\":42}", rs.getString(1));
     }
@@ -377,7 +449,9 @@ public class JSON1Test {
     public void json_remove_Test6() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_remove('{\"x\":25,\"y\":42}','$.y')");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery("select json_remove('{\"x\":25,\"y\":42}','$.y')");
         assertTrue(rs.next());
         assertEquals("{\"x\":25}", rs.getString(1));
     }
@@ -386,7 +460,9 @@ public class JSON1Test {
     public void json_remove_Test7() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_remove('{\"x\":25,\"y\":42}','$')");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery("select json_remove('{\"x\":25,\"y\":42}','$')");
         assertTrue(rs.next());
         assertEquals(null, rs.getString(1));
     }
@@ -395,7 +471,9 @@ public class JSON1Test {
     public void json_type_Test1() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_type('{\"a\":[2,3.5,true,false,null,\"x\"]}')");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery("select json_type('{\"a\":[2,3.5,true,false,null,\"x\"]}')");
         assertTrue(rs.next());
         assertEquals("object", rs.getString(1));
     }
@@ -404,7 +482,10 @@ public class JSON1Test {
     public void json_type_Test2() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_type('{\"a\":[2,3.5,true,false,null,\"x\"]}','$')");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery(
+                                "select json_type('{\"a\":[2,3.5,true,false,null,\"x\"]}','$')");
         assertTrue(rs.next());
         assertEquals("object", rs.getString(1));
     }
@@ -413,7 +494,10 @@ public class JSON1Test {
     public void json_type_Test3() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_type('{\"a\":[2,3.5,true,false,null,\"x\"]}','$.a')");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery(
+                                "select json_type('{\"a\":[2,3.5,true,false,null,\"x\"]}','$.a')");
         assertTrue(rs.next());
         assertEquals("array", rs.getString(1));
     }
@@ -422,7 +506,10 @@ public class JSON1Test {
     public void json_type_Test4() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_type('{\"a\":[2,3.5,true,false,null,\"x\"]}','$.a[0]')");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery(
+                                "select json_type('{\"a\":[2,3.5,true,false,null,\"x\"]}','$.a[0]')");
         assertTrue(rs.next());
         assertEquals("integer", rs.getString(1));
     }
@@ -431,7 +518,10 @@ public class JSON1Test {
     public void json_type_Test5() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_type('{\"a\":[2,3.5,true,false,null,\"x\"]}','$.a[1]')");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery(
+                                "select json_type('{\"a\":[2,3.5,true,false,null,\"x\"]}','$.a[1]')");
         assertTrue(rs.next());
         assertEquals("real", rs.getString(1));
     }
@@ -440,7 +530,10 @@ public class JSON1Test {
     public void json_type_Test6() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_type('{\"a\":[2,3.5,true,false,null,\"x\"]}','$.a[2]')");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery(
+                                "select json_type('{\"a\":[2,3.5,true,false,null,\"x\"]}','$.a[2]')");
         assertTrue(rs.next());
         assertEquals("true", rs.getString(1));
     }
@@ -449,7 +542,10 @@ public class JSON1Test {
     public void json_type_Test7() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_type('{\"a\":[2,3.5,true,false,null,\"x\"]}','$.a[3]')");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery(
+                                "select json_type('{\"a\":[2,3.5,true,false,null,\"x\"]}','$.a[3]')");
         assertTrue(rs.next());
         assertEquals("false", rs.getString(1));
     }
@@ -458,7 +554,10 @@ public class JSON1Test {
     public void json_type_Test8() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_type('{\"a\":[2,3.5,true,false,null,\"x\"]}','$.a[4]')");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery(
+                                "select json_type('{\"a\":[2,3.5,true,false,null,\"x\"]}','$.a[4]')");
         assertTrue(rs.next());
         assertEquals("null", rs.getString(1));
     }
@@ -467,7 +566,10 @@ public class JSON1Test {
     public void json_type_Test9() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_type('{\"a\":[2,3.5,true,false,null,\"x\"]}','$.a[5]')");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery(
+                                "select json_type('{\"a\":[2,3.5,true,false,null,\"x\"]}','$.a[5]')");
         assertTrue(rs.next());
         assertEquals("text", rs.getString(1));
     }
@@ -476,7 +578,10 @@ public class JSON1Test {
     public void json_type_Test10() throws SQLException {
         Connection conn = getConnection();
 
-        ResultSet rs = conn.createStatement().executeQuery("select json_type('{\"a\":[2,3.5,true,false,null,\"x\"]}','$.a[6]')");
+        ResultSet rs =
+                conn.createStatement()
+                        .executeQuery(
+                                "select json_type('{\"a\":[2,3.5,true,false,null,\"x\"]}','$.a[6]')");
         assertTrue(rs.next());
         assertEquals(null, rs.getString(1));
     }
@@ -505,14 +610,23 @@ public class JSON1Test {
 
         conn.createStatement().execute("create table user (name, phone)");
 
-        conn.createStatement().execute("insert into user values('james', json_array('704-100-0000','604-100-0000'))");
-        conn.createStatement().execute("insert into user values('sally', json_array('604-200-0000','404-200-0000'))");
-        conn.createStatement().execute("insert into user values('frank', json_array('704-200-0000','604-200-0000'))");
-        conn.createStatement().execute("insert into user values('harry', json_array('504-200-0000','304-200-0000'))");
+        conn.createStatement()
+                .execute(
+                        "insert into user values('james', json_array('704-100-0000','604-100-0000'))");
+        conn.createStatement()
+                .execute(
+                        "insert into user values('sally', json_array('604-200-0000','404-200-0000'))");
+        conn.createStatement()
+                .execute(
+                        "insert into user values('frank', json_array('704-200-0000','604-200-0000'))");
+        conn.createStatement()
+                .execute(
+                        "insert into user values('harry', json_array('504-200-0000','304-200-0000'))");
 
-        String q = "SELECT DISTINCT user.name"
-            + " FROM user, json_each(user.phone)"
-            + " where json_each.value LIKE '704-%'";
+        String q =
+                "SELECT DISTINCT user.name"
+                        + " FROM user, json_each(user.phone)"
+                        + " where json_each.value LIKE '704-%'";
 
         ResultSet rs = conn.createStatement().executeQuery(q);
         assertTrue(rs.next());
@@ -528,17 +642,22 @@ public class JSON1Test {
 
         conn.createStatement().execute("create table user (name, phone)");
 
-        conn.createStatement().execute("insert into user values('james', json_array('704-100-0000','604-100-0000'))");
+        conn.createStatement()
+                .execute(
+                        "insert into user values('james', json_array('704-100-0000','604-100-0000'))");
         conn.createStatement().execute("insert into user values('sally', '604-200-0000')");
         conn.createStatement().execute("insert into user values('frank', '704-200-0000')");
-        conn.createStatement().execute("insert into user values('harry', json_array('504-200-0000','304-200-0000'))");
+        conn.createStatement()
+                .execute(
+                        "insert into user values('harry', json_array('504-200-0000','304-200-0000'))");
 
-        String q = "SELECT name FROM user WHERE phone LIKE '705-%'"
-            + " UNION"
-            + " SELECT user.name"
-            + " FROM user, json_each(user.phone)"
-            + " WHERE json_valid(user.phone)"
-            + " AND json_each.value LIKE '704-%'";
+        String q =
+                "SELECT name FROM user WHERE phone LIKE '705-%'"
+                        + " UNION"
+                        + " SELECT user.name"
+                        + " FROM user, json_each(user.phone)"
+                        + " WHERE json_valid(user.phone)"
+                        + " AND json_each.value LIKE '704-%'";
 
         ResultSet rs = conn.createStatement().executeQuery(q);
         assertTrue(rs.next());
@@ -554,9 +673,10 @@ public class JSON1Test {
 
         conn.createStatement().execute("insert into big values(json_object('a',2,'c',4))");
 
-        String q = "SELECT big.rowid, fullkey, value"
-            + " FROM big, json_tree(big.json)"
-            + " WHERE json_tree.type NOT IN ('object', 'array')";
+        String q =
+                "SELECT big.rowid, fullkey, value"
+                        + " FROM big, json_tree(big.json)"
+                        + " WHERE json_tree.type NOT IN ('object', 'array')";
 
         ResultSet rs = conn.createStatement().executeQuery(q);
         assertTrue(rs.next());
@@ -580,9 +700,10 @@ public class JSON1Test {
 
         conn.createStatement().execute("insert into big values(json_object('a',2,'c',4))");
 
-        String q = "SELECT big.rowid, fullkey, atom"
-            + " FROM big, json_tree(big.json)"
-            + " WHERE atom IS NOT NULL";
+        String q =
+                "SELECT big.rowid, fullkey, atom"
+                        + " FROM big, json_tree(big.json)"
+                        + " WHERE atom IS NOT NULL";
 
         ResultSet rs = conn.createStatement().executeQuery(q);
         assertTrue(rs.next());
@@ -597,6 +718,4 @@ public class JSON1Test {
 
         assertFalse(rs.next());
     }
-
 }
-
